Struct phoenix_core::crossover::Crossover
source · pub struct Crossover { /* private fields */ }Expand description
Crossover structure containing obfuscated encrypted data
Implementations
sourceimpl Crossover
impl Crossover
sourcepub fn to_hash_inputs(&self) -> [BlsScalar; 6]
pub fn to_hash_inputs(&self) -> [BlsScalar; 6]
Represent the crossover as a sequence of scalars to be used as input for sponge hash functions
It is composed by 3 scalars, in order:
- Value commitment X
- Value commitment Y
- Nonce
And also appends the scalars that composes the PoseidonCipher
sourcepub const fn nonce(&self) -> &BlsScalar
pub const fn nonce(&self) -> &BlsScalar
Returns the Nonce used for the encrypt / decrypt of data for this note
sourcepub const fn value_commitment(&self) -> &JubJubExtended
pub const fn value_commitment(&self) -> &JubJubExtended
Returns the value commitment H(value, blinding_factor)
sourcepub const fn encrypted_data(&self) -> &PoseidonCipher
pub const fn encrypted_data(&self) -> &PoseidonCipher
Returns the encrypted data